==> qtjambi-qt3dquickscene2d-6.4.4-sources.jar: io/qt/qt3d/render/quick/scene2d/QtJambi_LibraryUtilities.java <==
package io.qt.qt3d.render.quick.scene2d;

import io.qt.*;
import static io.qt.QtUtilities.*;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 4;

    final static int qtJambiPatch = 4;

    final static InternalAccess internal;

    static{
        try {
            initializePackage("io.qt.internal");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly, "macos", "linux");
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Qml", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QmlModels", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Quick", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("ShaderTools", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("VirtualKeyboard", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WaylandEglClientHwIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.ProvideOnly, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Concurrent", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Network", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DCore", LibraryRequirementMode.Mandatory);
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("OpenGL", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Qml", LibraryRequirementMode.Mandatory);
            loadQtLibrary("DBus", LibraryRequirementMode.Optional);
            loadQtLibrary("QmlModels", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Quick", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DRender", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DQuick", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DQuickScene2D", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("3DQuickScene2D");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-qt3dquickscene2d-6.5.1-sources.jar: io/qt/qt3d/render/quick/scene2d/QtJambi_LibraryUtilities.java <==
package io.qt.qt3d.render.quick.scene2d;

import io.qt.*;
import static io.qt.QtUtilities.*;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 5;

    final static int qtJambiPatch = 1;

    final static InternalAccess internal;

    static{
        try {
            initializePackage("io.qt.core");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly, "macos", "linux");
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Qml", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QmlModels", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Quick", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("ShaderTools", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("VirtualKeyboard", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WaylandEglClientHwIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.ProvideOnly, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Concurrent", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Network", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DCore", LibraryRequirementMode.Mandatory);
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("OpenGL", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Qml", LibraryRequirementMode.Mandatory);
            loadQtLibrary("DBus", LibraryRequirementMode.Optional);
            loadQtLibrary("QmlModels", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Quick", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DRender", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DQuick", LibraryRequirementMode.Mandatory);
            loadQtLibrary("3DQuickScene2D", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("3DQuickScene2D");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
